
## CATO-CLI - mutation.licensing.updateCommercialLicense:
[Click here](https://api.catonetworks.com/documentation/#mutation-mutation.licensing.updateCommercialLicense) for documentation on this operation.

### Usage for mutation.licensing.updateCommercialLicense:

```bash
catocli mutation licensing updateCommercialLicense -h

catocli mutation licensing updateCommercialLicense <json>

catocli mutation licensing updateCommercialLicense --json-file mutation.licensing.updateCommercialLicense.json

catocli mutation licensing updateCommercialLicense '{"updateCommercialLicenseInput":{"licenseId":"id","startDate":"example_value"}}'

catocli mutation licensing updateCommercialLicense '{
    "updateCommercialLicenseInput": {
        "licenseId": "id",
        "startDate": "example_value"
    }
}'
```

#### Operation Arguments for mutation.licensing.updateCommercialLicense ####

`accountId` [ID] - (required) N/A    
`updateCommercialLicenseInput` [UpdateCommercialLicenseInput] - (required) N/A    
